#!/usr/bin/env python2
# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand, CommandError

from club.models import Club
from ldap_inp import LdapEleve

import csv


class Command(BaseCommand):
    args = "<fichier.csv> <club_ident>"
    help = "Ajouter des membres à un club à partir d'un csv de noms"

    def handle(self, *args, **options):
        if len(args) == 2:
            csv_file, club_id = args
        else:
            raise CommandError("Pas assez d'argument")

        # Club
        clubs = Club.objects.filter(ident=club_id)
        if len(clubs):
            club = clubs[0]
        else:
            raise Club.DoesNotExist(f"Club « {club_id} » non trouvé.")

        # dico to save names
        membres = []
        query = dict({"nom": "", "prenom": ""})
        query_keys = sorted(query.keys())

        with open(csv_file, "r") as f:
            freader = csv.reader(f, delimiter=";", quotechar='"')
            for j, ligne in enumerate(freader):
                if j != 0:
                    eleve = query
                    for i, data in enumerate(query_keys):
                        eleve[data] = ligne[i]

                    # parsing
                    eleve["nom"] = eleve["nom"].title().strip()
                    eleve["prenom"] = eleve["prenom"].title().strip()

                    # LdapEleve
                    etus = LdapEleve.objects.filter(sn=eleve["nom"], givenName=eleve["prenom"])
                    if len(etus):
                        etu = etus[0]
                        if etu.inscritAE:
                            # dans club
                            membres.append(etu.uid)
                        else:
                            print("{eleve['prenom']} {eleve['nom']} n'est pas cotisant à l'AE")
                    else:
                        print(f"{eleve['prenom']} {eleve['nom']} n'est pas dans le LDAP")

        club.ajouter_membres(membres)
